@@ -5,6 +5,7 @@ Licensed under the terms of the MIT license
 """
 
 import os
+import toxopy
 import pandas as pd
 from math import sqrt
 from numpy import nan
@@ -12,7 +13,6 @@ from tqdm import tqdm
 from rich.console import Console
 from pathlib import Path
 from glob import glob
-from toxopy import trials
 from dirtyR import smooth
 from shutil import move
 from subprocess import Popen
@@ -26,13 +26,16 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
     """
 
     console = Console()
-    trls = trials()
+    trls = toxopy.trials()
 
     def gg(i):
         return sorted(glob(inDIR + f'/*_{i}.csv'))
 
     chwo, oh, ch = gg('chwo'), gg('oh'), gg('ch')
 
+    if len(chwo) != len(oh) != len(ch):
+        raise ValueError('Some data are missing!')
+
     for cat_head, owner_hand, cat_alone in zip(chwo, oh, ch):
 
         cat = Path(cat_head).stem[:-5]
@@ -66,7 +69,7 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
                         tls.append('FT')
                     else:
                         for q, p in zip(range(0, 4), trls[2:][::2]):
-                            if tt[q] <= i < tt[q+1]:
+                            if tt[q] <= i < tt[q + 1]:
                                 tls.append(p)
 
             elif trial_type == "cat":
@@ -88,12 +91,10 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
         for i, j in zip([cat_head, owner_hand, cat_alone],
                         ['owner', 'owner', 'cat']):
             file_name = f'{outDIR}/{Path(i).stem}_improved.csv'
-            improve_dlc_csv(
-                i, trial_type=j, file_name=file_name)
+            improve_dlc_csv(i, trial_type=j, file_name=file_name)
 
         if only_improve_csv is True:
             return None
-
         """Calculate the distance between cat and owner."""
 
         def dt(file_name):
@@ -109,8 +110,8 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
 
         ds = []
 
-        console.print(
-            "\nCALCULATING THE DISTANCE BETWEEN CAT AND OWNER", style="bold green")
+        console.print("\nCALCULATING THE DISTANCE BETWEEN CAT AND OWNER",
+                      style="bold green")
 
         for i, j in tqdm(zip(df_cat['indx'], df_owner['indx'])):
 
@@ -152,9 +153,7 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
 
             elif name == 'CA':
                 console.print("\nCAT ALONE TRIALS", style="bold blue")
-
             """Calculate the cat's traveled distance."""
-
             def calculateDistance(x1, y1, x2, y2):
                 dist = sqrt((x2 - x1)**2 + (y2 - y1)**2)
                 return dist
@@ -163,8 +162,6 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
 
             cat_dst = []
 
-            n = len(df_alt)
-
             console.print("\nCALCULATING THE CAT'S TRAVELED DISTANCE",
                           style="bold green")
 
@@ -181,7 +178,6 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
             cat_dst[0] = nan
 
             fdf = pd.DataFrame(cat_dst, columns=['cat_distance'])
-
             """Calculate cat velocity."""
 
             def calculateVelocity(dist, time):
@@ -203,7 +199,6 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
                 velocity_ls.append(float(calculateVelocity(d, 0.033)))
 
             fdf['velocity'] = velocity_ls
-
             """Calculate the cat's movement state."""
 
             moving, notMoving = [], []
@@ -224,7 +219,6 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
                     notMoving.append(1)
 
             fdf['moving'], fdf['not_moving'] = moving, notMoving
-
             """Calculate cat acceleration."""
 
             def calculateAcc(vi, vf, ti, tf):
@@ -235,18 +229,17 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
             console.print("\nCALCULATING THE CAT'S ACCELERATION",
                           style="bold green")
 
-            def a(u, v, d):
-                return d.iloc[q - u][v].astype('float')
-
             for q in tqdm(range(0, len(df_alt))):
 
+                def a(u, v, d):
+                    return d.iloc[q - u][v].astype('float')
+
                 vi, vf = a(0, 'velocity', fdf), a(1, 'velocity', fdf)
                 ti, tf = a(0, 'time', df_alt), a(1, 'time', df_alt)
 
                 acc.append(float(calculateAcc(vi, vf, ti, tf)))
 
             fdf['acceleration'] = acc
-
             """Clean data."""
 
             if name == 'WO':
@@ -296,19 +289,19 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
 
         if 'Darwin' in platform():
             p = Popen(['open', f'{outDIR}/smooth.r'])
-            returncode = p.wait()
         else:
             pass
 
         ans = input('Done smoothing? (y) ')
         if ans.lower() == "y":
             break
-        else:
-            continue
+        continue
 
     for x in ['/*', '/.*']:
-        [os.remove(x)
-         for x in glob(f'{outDIR}/{x}') if os.path.isfile(x) is True]
+        [
+            os.remove(x) for x in glob(f'{outDIR}/{x}')
+            if os.path.isfile(x) is True
+        ]
 
     def one_cat_one_file(ca_dir, wo_dir, outDIR):
         """
@@ -316,8 +309,8 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
         'wo_dir' is the dir with with_owner_improved csv files
         """
 
-        cat_alone, with_owner = glob(
-            ca_dir + '/*.csv'), glob(wo_dir + '/*.csv')
+        cat_alone, with_owner = glob(f'{ca_dir}/*.csv'), glob(
+            f'{wo_dir}/*.csv')
 
         console.print('\nCONCATENATING FILES...', style='bold blue')
 
@@ -328,10 +321,9 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
             if cat1 == cat2:
                 files.append(f1), files.append(f2)
             else:
-                raise ValueError('Something is wrong!')
+                raise ValueError(f'Cannot find all required files for {cat1}!')
 
-            combined_csv = pd.concat(
-                [pd.read_csv(f) for f in files])
+            combined_csv = pd.concat([pd.read_csv(f) for f in files])
 
             combined_csv.to_csv(f'{outDIR}/{cat1}.csv',
                                 index=False,
@@ -361,30 +353,30 @@ def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
 
                 diff = max(time) - min(time)
 
-                if trial == trial and diff > ttime:
-                    raise ValueError('Failed!', cat, trial, diff)
+                if diff > ttime:
+                    raise ValueError(
+                        f'Cannot correct time! Check {cat} data'
+                        f' in {trial} (diff value: {diff})'
+                    )
 
-                elif trial == trial and diff < ttime:
+                if diff < ttime:
 
                     fdf = pd.DataFrame(df[df['trial'] == trial])
 
-                    C = list(df.columns)
-                    C = [x for x in C if not 'owner' in x and not x.startswith(
-                        'd') and not x.endswith('1')]
-
-                    fdf = fdf[C]
                     fdf['time'] = df[df['trial'] == trial]['time'] + ad
 
-                    fdf.to_csv(f'{outDIR}/{cat}_{trial}.csv',
+                    fdf.to_csv(f'{outDIR}/.{cat}_{trial}.csv',
                                index=False,
                                encoding='utf-8-sig')
 
-            fs = glob(f'{outDIR}/{cat}_*.csv')
+            fs = glob(f'{outDIR}/.{cat}_*.csv')
 
             ccsv = pd.concat([pd.read_csv(i) for i in fs])
-
             ccsv = ccsv.sort_values(by=['time'])
 
+            toxopy.set_status(cat, ccsv)
+            ccsv = ccsv[toxopy.combined_behaviors()]
+
             ccsv.to_csv(f'{outDIR}/{cat}.csv',
                         index=False,
                         encoding='utf-8-sig')
